@@ -1,17 +1,17 @@
-from .node import Node
 from .baseobject import BaseObject
+from .meta import Meta
+from .node import Node
+
 
 class Network(BaseObject):
     keys = {
-        "name": "name",
+        "meta": "meta",
         "config": "config",
-        "version": "version",
-        "api_port_base": "api_port_base",
-        "network_port_base": "network_port_base",
-        "session_port_base": "session_port_base",
         "nodes": "nodes",
-        "slug": "nodes_slug"
+        "slug": "nodes_slug",
+        "networks": "networks",
     }
 
     def post_init(self):
         self.nodes = [Node(subdata) for subdata in self.nodes]
+        self.meta = Meta(self.meta)
